# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ugc Service."""

__version__ = "2.19.4"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .get_followed_content import GetFollowedContent
from .get_followed_users import GetFollowedUsers
from .get_public_followers import GetPublicFollowers
from .get_public_following import GetPublicFollowing
from .update_user_follow_status import UpdateUserFollowStatus
